@@ -27,17 +27,21 @@
 /*******************************************************************************/
 #include "weather-common.h"
 #include "weather-gps.h"
+#ifdef RELEASE
+#undef DEBUGFUNCTIONCALL
+#endif
 /*******************************************************************************/
-#ifdef HILDON
+#ifdef OS2008
 
 void
 get_nearest_station( double lat, double lon, Station *result)
 {
     FILE		*fh;
     char		buffer[512];
-#ifndef RELEASE
-    fprintf(stderr,"BEGIN %s(): \n", __PRETTY_FUNCTION__);
-#endif     
+    char		filename[4096];
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     Region_item  region;
     GtkListStore *stations_list = NULL;
     GtkTreeIter  iter;
@@ -49,10 +53,11 @@ get_nearest_station( double lat, double lon, Station *result)
                  distance,
 		 min_distance = 40000;
 
-
-    fh = fopen(REGIONSFILE, "rt");
+    filename[0] = 0;
+    snprintf(filename, sizeof(filename) - 1,"%s%s",weather_sources[app->config->weather_source].db_path,REGIONSFILE);
+    fh = fopen(filename, "rt");
     if(!fh){
-	fprintf(stderr, "\nCan't read file %s: %s", REGIONSFILE,
+	fprintf(stderr, "\nCan't read file %s: %s", filename,
 		strerror(errno));
 	return;
     }
@@ -63,8 +68,8 @@ get_nearest_station( double lat, double lon, Station *result)
         parse_region_string(buffer,&region);
 	/* Checking insiding point in to region */
         if ( lat >= region.minlat && lat <= region.maxlat && lon >= region.minlon && lon <= region.maxlon){
-	    
-            stations_list = create_items_list(LOCATIONSFILE, region.start,region.end, NULL);
+            stations_list = create_items_list(weather_sources[app->config->weather_source].db_path,
+			    LOCATIONSFILE, region.start, region.end, NULL);
             valid =  gtk_tree_model_get_iter_first(GTK_TREE_MODEL(stations_list), &iter);
             
             while (valid){
@@ -77,7 +82,6 @@ get_nearest_station( double lat, double lon, Station *result)
                 		                -1);
 		/* Calculating distance */				
 		distance = calculate_distance(lat,lon,station_latitude,station_longtitude);
-
 		if (distance<min_distance){
 
 		    /* New minimal distance */
@@ -123,14 +127,17 @@ get_nearest_station( double lat, double lon, Station *result)
         }          
     }
     fclose(fh);
-#ifndef RELEASE
-    fprintf(stderr,"END %s(): \n", __PRETTY_FUNCTION__);
-#endif 
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
 }
 /*******************************************************************************/
 static void
 gps_location_changed (LocationGPSDevice *device, gpointer userdata)
 {
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     if (!app->config->gps_station)
         return;
     if (device->fix->fields & LOCATION_GPS_DEVICE_LATLONG_SET){
@@ -142,28 +149,84 @@ gps_location_changed (LocationGPSDevice *device, gpointer userdata)
 void
 initial_gps_connect(void)
 { 
-#ifndef RELEASE
-    fprintf(stderr,"BEGIN %s(): \n", __PRETTY_FUNCTION__);
-#endif 
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     app->gps_device = g_object_new (LOCATION_TYPE_GPS_DEVICE, NULL);
     app->gps_id_connection = g_signal_connect (app->gps_device, "changed", G_CALLBACK (gps_location_changed), NULL);
-#ifndef RELEASE
-    fprintf(stderr,"END %s(): \n", __PRETTY_FUNCTION__);
-#endif 
     
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif    
 }
 /*******************************************************************************/
 void
 deinitial_gps_connect(void)
 {
-#ifndef RELEASE
-    fprintf(stderr,"BEGIN %s(): \n", __PRETTY_FUNCTION__);
-#endif 
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     g_signal_handler_disconnect (app->gps_device,app->gps_id_connection);
     g_object_unref(app->gps_device);
-#ifndef RELEASE
-    fprintf(stderr,"END %s(): \n", __PRETTY_FUNCTION__);
-#endif     
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+}
+/*******************************************************************************/
+void delete_all_gps_stations(void){
+    gboolean		valid;
+    GtkTreeIter		iter;
+    gchar		*station_name = NULL,
+	    		*station_code = NULL;
+    gboolean		is_gps = FALSE;
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(app->user_stations_list),
+                                                  &iter);
+    while(valid){
+    		gtk_tree_model_get(GTK_TREE_MODEL(app->user_stations_list),
+                        	    &iter,
+                    		    0, &station_name,
+                        	    1, &station_code,
+				    2, &is_gps,
+                        	    -1);
+    		if(is_gps){
+		    if(app->config->current_station_id &&
+			!strcmp(app->config->current_station_id,station_code) &&
+			app->config->current_station_name && 
+			!strcmp(app->config->current_station_name,station_name)){
+		        /* deleting current station */
+		        app->gps_must_be_current = TRUE;
+		       	g_free(app->config->current_station_id);
+            		g_free(app->config->current_station_name);					
+		        app->config->current_station_id = NULL;
+			app->config->current_station_name = NULL;
+        		app->config->previos_days_to_show = app->config->days_to_show;
+            	    }
+		    else
+			app->gps_must_be_current = FALSE;		    
+		    valid = gtk_list_store_remove(app->user_stations_list, &iter);
+		}else
+		    valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(app->user_stations_list),
+                                                        &iter);					
+							
+    	    }
+    /* Set new current_station */
+    if(!app->config->current_station_id){
+	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(app->user_stations_list),
+                                                  &iter);
+	if(valid){
+	    gtk_tree_model_get(GTK_TREE_MODEL(app->user_stations_list),
+                        	    &iter,
+                    		    0, &station_name,
+                        	    1, &station_code,
+				    2, &is_gps,
+                        	    -1);
+	    app->config->current_station_id = g_strdup(station_code);
+	    app->config->current_station_name = g_strdup(station_name);
+	}		    	
+    }
 }
 /*******************************************************************************/
 #endif
