@@ -306,9 +306,9 @@ int calculate_offset_of_day(int count_day){
 
     strptime(date_in_string, "%b %d %Y %T", tm);
     /* Check New Year */
-    if((current_month == 11) && (tm->tm_mon == 0)){
+    if((current_month == 0) && (tm->tm_mon == 11)){
 	sprintf(date_in_string, "%s %i 00:00:00",
-		item_value(last_day, "24h_date"), year + 1);
+		item_value(first_day, "24h_date"), year - 1);
 	strptime(date_in_string, "%b %d %Y %T", tm);
     }
     date_time = mktime(tm);
@@ -316,10 +316,11 @@ int calculate_offset_of_day(int count_day){
     pre_offset = (double)(abs(current_day - date_time));
     pre_offset /= 24.0F * 60.0F * 60.0F;
     offset = (int)( round(pre_offset) );
-
+    
     if(offset >= Max_count_weather_day)
 	offset = Max_count_weather_day;
     
+    
     return offset;
 }
 /*******************************************************************************/
@@ -417,6 +418,9 @@ void draw_home_window(gint count_day){
 	    last = (GSList*)((g_slist_last(tmp))->data);
 	}
     }
+    
+    /* Init popup Context menu */
+    menu_init();
 
     i = 0;
     while(i < app->config->days_to_show){
@@ -538,7 +542,8 @@ void draw_home_window(gint count_day){
 						    app->config->transparency,
 						    TRUE,
 						    &(app->config->background_color));
-	g_signal_connect(tmp_button->button, "button-press-event",
+
+	g_signal_connect(tmp_button->button, "button-release-event",
 			    G_CALLBACK(weather_window_popup),
 			    (is_na_day ? (GINT_TO_POINTER(-1)) : (GINT_TO_POINTER(i))));
 	add_item2object(&(app->buttons), (void*)tmp_button);
@@ -631,7 +636,7 @@ void redraw_home_window(gboolean first_start){
     app->count_day = count_day;	/* store days number from xml file */
     draw_home_window(count_day);
 #ifdef DEBUGFUNCTIONCALL
-    STOP_FUNCTION;
+    END_FUNCTION;
 #endif
 }
 /*******************************************************************************/
@@ -898,8 +903,11 @@ void menu_init(void){
                                                         &iter);
     }
     gtk_widget_show_all(GTK_WIDGET(app->contextmenu));
-    gtk_widget_tap_and_hold_setup(app->main_window, GTK_WIDGET(app->contextmenu),
-				    NULL, 0);
+
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+
 }
 /*******************************************************************************/
 /* For Combination layout */
@@ -1186,8 +1194,7 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency,
 	previos_station_name_btn = gtk_event_box_new();
 	set_background_color(previos_station_name_btn, &(app->config->background_color));
 	
-	gtk_widget_set_events(previos_station_name_btn,
-				GDK_BUTTON_RELEASE_MASK | GDK_BUTTON_PRESS_MASK);
+	gtk_widget_set_events(previos_station_name_btn, GDK_BUTTON_PRESS_MASK);
 	previos_station_name = gtk_label_new(NULL);
 	gtk_label_set_markup(GTK_LABEL(previos_station_name), buffer);
 	gtk_label_set_justify(GTK_LABEL(previos_station_name), GTK_JUSTIFY_CENTER);
@@ -1206,8 +1213,7 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency,
 	next_station_name_btn = gtk_event_box_new();
 	set_background_color(next_station_name_btn, &(app->config->background_color));
 	
-	gtk_widget_set_events(next_station_name_btn, GDK_BUTTON_RELEASE_MASK |
-						     GDK_BUTTON_PRESS_MASK);
+	gtk_widget_set_events(next_station_name_btn, GDK_BUTTON_PRESS_MASK);
 	next_station_name = gtk_label_new(NULL);
 	gtk_label_set_markup(GTK_LABEL(next_station_name), buffer);
 	gtk_label_set_justify(GTK_LABEL(next_station_name), GTK_JUSTIFY_CENTER);
@@ -1248,8 +1254,7 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency,
 	station_box = gtk_hbox_new(FALSE, 0);
 	station_name_btn = gtk_event_box_new();
 	set_background_color(station_name_btn, &(app->config->background_color));		
-	gtk_widget_set_events(station_name_btn, GDK_BUTTON_RELEASE_MASK |
-						GDK_BUTTON_PRESS_MASK);
+	gtk_widget_set_events(station_name_btn, GDK_BUTTON_PRESS_MASK);
 	station_name = gtk_label_new(NULL);
 	gtk_label_set_markup(GTK_LABEL(station_name), buffer);
 	gtk_label_set_justify(GTK_LABEL(station_name), GTK_JUSTIFY_CENTER);
@@ -1428,19 +1433,19 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency,
 		    (GtkAttachOptions)0, (GtkAttachOptions)0, 0, 0);
 /* Connect signal button */
     if(previos_station_name_btn)
-	g_signal_connect(previos_station_name_btn, "button-release-event",
+	g_signal_connect(previos_station_name_btn, "button-press-event",
 			    G_CALLBACK(change_station_prev), NULL);
     if(next_station_name_btn)
-	g_signal_connect(next_station_name_btn, "button-release-event",
+	g_signal_connect(next_station_name_btn, "button-press-event",
 			    G_CALLBACK(change_station_next), NULL);  		    
     if(station_name_btn){
-        g_signal_connect(station_name_btn, "button-release-event",
+        g_signal_connect(station_name_btn, "button-press-event",
 			    G_CALLBACK(change_station_next), NULL);  		    
-	gtk_container_set_focus_child(GTK_CONTAINER(panel), station_name_btn);
-	menu_init();
+	gtk_container_set_focus_child(GTK_CONTAINER(panel), station_name_btn);	
     }
     else
 	gtk_container_set_focus_child(GTK_CONTAINER(panel), panel);
+
     if(station_name_btn)
 	g_object_unref(station_name_btn);
 }
@@ -1537,8 +1542,10 @@ WDB* create_weather_day_button(const char *text, const char *icon,
 	return NULL;
     /* create day button */
     new_day_button->button = gtk_event_box_new();
-    gtk_widget_set_events(new_day_button->button, GDK_BUTTON_RELEASE_MASK |
-						  GDK_BUTTON_PRESS_MASK);
+    gtk_widget_set_events(new_day_button->button, GDK_BUTTON_RELEASE_MASK);
+    gtk_widget_tap_and_hold_setup(new_day_button->button, GTK_WIDGET(app->contextmenu),
+				    NULL, 0);
+
 #ifdef OS2008
     gtk_event_box_set_visible_window(GTK_EVENT_BOX(new_day_button->button), FALSE);
 #else
