@@ -396,7 +396,7 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
 			NULL);
     /* Close button */
     close_button = create_button_with_image(BUTTON_ICONS, "close", 40, FALSE, FALSE);
-    g_signal_connect(G_OBJECT(close_button), "button_press_event",
+    g_signal_connect(G_OBJECT(close_button), "button_release_event",
                         G_CALLBACK(popup_close_button_handler),
 			(gpointer)app->popup_window);
 
